#include "SvgShapeElement.h"

#include "XmlAttribute.h"

#include <sstream>

SvgShapeElement::SvgShapeElement(const std::string& tagName)
    : SvgElement(tagName)
{

}

void SvgShapeElement::setNoFill()
{
    auto attr = std::make_unique<XmlAttribute>("fill");
    attr->setValue("none");
    addAttribute(std::move(attr));
}

void SvgShapeElement::setNoStroke()
{
    auto attr = std::make_unique<XmlAttribute>("stroke");
    attr->setValue("none");
    addAttribute(std::move(attr));
}

void SvgShapeElement::setFill(const Color& fill)
{
    auto attr = std::make_unique<XmlAttribute>("fill");

    std::stringstream sstr;
    sstr << "rgb(" << fill.getR() << "," << fill.getG() << "," << fill.getB() << ")";
    attr->setValue(sstr.str());

    addAttribute(std::move(attr));
}

void SvgShapeElement::setStrokeWidth(double width)
{
    auto attr = std::make_unique<XmlAttribute>("stroke-width");
    attr->setValue(std::to_string(width));

    addAttribute(std::move(attr));
}

void SvgShapeElement::setStrokeColor(const Color& stroke)
{
    auto attr = std::make_unique<XmlAttribute>("stroke");

    std::stringstream sstr;
    sstr << "rgb(" << stroke.getR() << "," << stroke.getG() << "," << stroke.getB() << ")";
    attr->setValue(sstr.str());

    addAttribute(std::move(attr));
}
